@@ -107,3 +107,14 @@ def read_image_gcs_b64(bucket, image_file):
     img_jpg = cv2.imencode('.jpeg', img_np)[1]
     image_b64 = base64.b64encode(img_jpg).decode('utf-8')
     return image_b64
+
+
+def get_file_list(bucket, prefix): 
+    client = storage.Client()
+
+    blobs = []
+    for blob in client.list_blobs(bucket, prefix):
+        blobs.append(blob)
+
+    return blobs 
+
